@@ -1,6 +1,6 @@
 """
 Frame
--------------------
+-----
 
 Contains the class definition of a ``TfsDataFrame``, inherited from the ``pandas`` ``DataFrame``, as well
 as a utility function to validate the correctness of a ``TfsDataFrame``.
@@ -9,7 +9,7 @@ import logging
 from collections import OrderedDict
 from contextlib import suppress
 from functools import partial, reduce
-from typing import Sequence, Union
+from typing import Sequence, Set, Union
 
 import numpy as np
 import pandas as pd
@@ -260,7 +260,7 @@ def concat(
     axes. Data manipulation is done by the ``pandas.concat`` function. Resulting headers are either
     merged according to the provided **how_headers** method or as given via **new_headers**.
 
-    ..warning::
+    .. warning::
         Please note that when using this function on many ``TfsDataFrames``, leaving the contents of the
         final headers dictionary to the automatic merger can become unpredictable. In this case it is
         recommended to provide the **new_headers** argument to ensure the final result, or leave both
@@ -304,6 +304,18 @@ def validate(
     Check if a data frame contains finite values only, strings as column names and no empty headers
     or column names.
 
+    .. admonition:: **Methodology**
+
+        This function performs several different checks on the provided dataframe:
+         1. Checking no single element is a `list` or `tuple`, which is done with a 
+            custom vectorized function applied column-by-column on the dataframe.
+         2. Checking for non-physical values in the dataframe, which is done by
+            applying the ``isna`` function with the right option context.
+         3. Checking for duplicates in either indices or columns.
+         4. Checking for column names that are not strings.
+         5. Checking for column names including spaces.
+
+
     Args:
         data_frame (Union[TfsDataFrame, pd.DataFrame]): the dataframe to check on.
         info_str (str): additional information to include in logging statements.
@@ -314,23 +326,30 @@ def validate(
     if non_unique_behavior.lower() not in ("warn", "raise"):
         raise KeyError("Invalid value for parameter 'non_unique_behavior'")
 
-    def is_not_finite(x):
-        try:
-            return ~np.isfinite(x)
-        except TypeError:  # most likely string
-            try:
-                return np.zeros(x.shape, dtype=bool)
-            except AttributeError:  # single entry
-                return np.zeros(1, dtype=bool)
+    # ----- Check that no element is a list / tuple in the dataframe ----- #
+    def _element_is_list(element):
+        return isinstance(element, (list, tuple))
+    _element_is_list = np.vectorize(_element_is_list)
 
-    boolean_df = data_frame.applymap(is_not_finite)
+    list_or_tuple_bool_df = data_frame.apply(_element_is_list)
+    if list_or_tuple_bool_df.to_numpy().any():
+        LOGGER.error(
+            f"DataFrame {info_str} contains list/tuple values at Index: "
+            f"{list_or_tuple_bool_df.index[list_or_tuple_bool_df.any(axis='columns')].tolist()}"
+        )
+        raise TfsFormatError("Lists or tuple elements are not accepted in a TfsDataFrame")
 
-    if boolean_df.to_numpy().any():
+    # -----  Check that no element is non-physical value in the dataframe ----- #
+    with pd.option_context('mode.use_inf_as_na', True):
+        inf_or_nan_bool_df = data_frame.isna()
+
+    if inf_or_nan_bool_df.to_numpy().any():
         LOGGER.warning(
             f"DataFrame {info_str} contains non-physical values at Index: "
-            f"{boolean_df.index[boolean_df.any(axis='columns')].tolist()}"
+            f"{inf_or_nan_bool_df.index[inf_or_nan_bool_df.any(axis='columns')].tolist()}"
         )
 
+    # Other sanity checks
     if data_frame.index.has_duplicates:
         LOGGER.warning("Non-unique indices found.")
         if non_unique_behavior.lower() == "raise":
@@ -350,8 +369,4 @@ def validate(
         LOGGER.debug(f"Space(s) found in TFS columns, dataframe {info_str} is invalid")
         raise TfsFormatError("TFS-Columns can not contain spaces.")
 
-    if hasattr(data_frame, "headers") and any(" " in h for h in data_frame.headers.keys()):
-        LOGGER.debug(f"Space(s) found in TFS header names, dataframe {info_str} is invalid")
-        raise TfsFormatError("TFS-Header names can not contain spaces.")
-
     LOGGER.debug(f"DataFrame {info_str} validated")
